@@ -630,6 +630,7 @@ class BeginTest(unittest.TestCase):
     def test_bind_db(self):
         _, env = testlib.temp_env()
         main = env.open_db(None)
+        self.assertRaises(ValueError, lambda: env.open_db(None, dupsort=True))
         sub = env.open_db(B('db1'))
 
         txn = env.begin(write=True, db=sub)
@@ -825,6 +826,7 @@ class SpareTxnTest(unittest.TestCase):
     def tearDown(self):
         testlib.cleanup()
 
+    @unittest.skip('Temporarily removed this functionality')
     def test_none(self):
         _, env = testlib.temp_env(max_spare_txns=0)
         assert 0 == reader_count(env)
